@@ -2,4 +2,4 @@ default_app_config = 'simpleui.apps.SimpleApp'
 
 
 def get_version():
-    return '2022.2'
+    return '2022.3.1'
